@@ -63,42 +63,42 @@ class OnlinePvtClient:
         body: FlashCalculationInput,
     ):
         """Perform flash calculation"""
-        return await self.__post_async("Calculation/CallFlash", body.to_dict(), FlashCalculationResult.from_dict)
+        return await self.__post_async("Calculation/Flash", body.to_dict(), FlashCalculationResult.from_dict)
 
     async def call_cloud_point_async(
         self,
         body: CloudPointCalculationInput,
     ):
         """Perform cloud point calculation"""
-        return await self.__post_async("Calculation/CallCloudPoint", body.to_dict(), CloudPointCalculationResult.from_dict)
+        return await self.__post_async("Calculation/CloudPoint", body.to_dict(), CloudPointCalculationResult.from_dict)
 
     async def call_flashed_properties_async(
         self,
         body: FlashedPropertyCalculationInput,
     ):
         """Perform flash property calculation"""
-        return await self.__post_async("Calculation/CallFlashedProperties", body.to_dict(), FlashedPropertyCalculationResult.from_dict)
+        return await self.__post_async("Calculation/FlashedProperties", body.to_dict(), FlashedPropertyCalculationResult.from_dict)
 
     async def call_unflashed_properties_async(
         self,
         body: UnflashedPropertyCalculationInput,
     ):
         """Perform un-flash property calculation"""
-        return await self.__post_async("Calculation/CallUnflashedProperties", body.to_dict(), UnflashedPropertyCalculationResult.from_dict)
+        return await self.__post_async("Calculation/UnflashedProperties", body.to_dict(), UnflashedPropertyCalculationResult.from_dict)
 
     async def call_sle_point_async(
         self,
         body: SlePointCalculationInput,
     ):
         """Perform SLE point calculation"""
-        return await self.__post_async("Calculation/CallSlePoint", body.to_dict(), SlePointCalculationResult.from_dict)
+        return await self.__post_async("Calculation/SlePoint", body.to_dict(), SlePointCalculationResult.from_dict)
 
     async def call_calculation_phasediagram_standard_async(
         self,
         body: PhasediagramFixedTemperaturePressureCalculationInput,
     ):
         """Perform Phasediagram standard calculation"""
-        return await self.__post_async("Calculation/CallCalculationPhasediagramStandard", body.to_dict(), PhasediagramFixedTemperaturePressureCalculationResult.from_dict)
+        return await self.__post_async("Calculation/PhasediagramStandard", body.to_dict(), PhasediagramFixedTemperaturePressureCalculationResult.from_dict)
 
     def get_flash_input(self):
         """Returns flash argument filled with standard input"""
